import unittest

from automon.integrations.seleniumWrapper.proxies_public import *


class ProxiesTest(unittest.TestCase):

    def test_proxy_site_spys(self):
        self.assertIsNotNone(proxy_site_spys())

    def test_proxy_site_free_proxy_list(self):
        self.assertIsNotNone(proxy_site_free_proxy_list())

    def test_proxy_get_random_proxy(self):
        self.assertIsNotNone(proxy_get_random_proxy())

    def test_proxy_filter_https_proxies(self):
        self.assertIsNotNone(proxy_filter_https_proxies())

    def test_proxy_filter_https_ips_and_ports(self):
        self.assertIsNotNone(proxy_filter_https_ips_and_ports())

    def test_proxy_filter_https_ips_and_ports_get_random(self):
        self.assertTrue(proxy_filter_https_ips_and_ports_get_random())


if __name__ == '__main__':
    unittest.main()



import unittest

import automon.integrations.facebook.groups


class MyTestCase(unittest.TestCase):
    def test_something(self):
        client = automon.integrations.facebook.FacebookGroups()

        if client._browser.webdriver:
            client.start(headless=False)

        pass


if __name__ == '__main__':
    unittest.main()



import unittest
import sys

from automon.integrations.mac.airport import Airport

airport = Airport()


class AirportTest(unittest.TestCase):

    def test_run(self):
        if airport.isReady():
            self.assertTrue(airport.run())

    def test_scan(self):
        if airport.isReady():
            self.assertTrue(airport.scan())
            self.assertTrue(airport.scan(0))

    def test_summary(self):
        if airport.isReady():
            self.assertTrue(airport.scan_summary())
            self.assertTrue(airport.scan_summary(0))

    def test_xml(self):
        if airport.isReady():
            scan = airport.scan_xml()
            if scan:
                self.assertTrue(scan)
            self.assertFalse(airport.scan_xml(0))

    def test_set_channel(self):
        if airport.isReady():
            pass
            # self.assertTrue(a.set_channel(10)

    def test_disassociate(self):
        if airport.isReady():
            pass
            # self.assertTrue(a.disassociate()

    def test_getinto(self):
        if airport.isReady():
            self.assertTrue(airport.getinfo())

    def test_create_psk(self):
        if airport.isReady():
            self.assertTrue(airport.create_psk(ssid='AAAAAAAA', passphrase='CALVIN'))


if __name__ == '__main__':
    unittest.main()



import random

from automon import log

logger = log.logging.getLogger(__name__)
logger.setLevel(log.INFO)


class RequestsConfig(object):

    def __init__(self, use_random_proxies: bool = False):
        self.proxies = []
        self.use_random_proxies = use_random_proxies

        # $ export HTTP_PROXY="http://10.10.1.10:3128"
        # $ export HTTPS_PROXY="http://10.10.1.10:1080"
        # $ export ALL_PROXY="socks5://10.10.1.10:3434"

    def __repr__(self):
        return f'{len(self.proxies)} proxies'

    def add_proxy(self, proxy: str):
        """add proxy"""
        new_proxy = self.create_proxy(http=proxy, https=proxy, ftp=proxy)
        if new_proxy not in self.proxies:
            logger.debug(f'RequestsConfig :: ADD PROXY :: {new_proxy}')
            self.proxies.append(new_proxy)

        logger.info(f'RequestsConfig :: ADD PROXY :: DONE')
        return self

    @staticmethod
    def create_proxy(http: str = None, https: str = None, ftp: str = None):
        """create proxy"""
        proxy = dict(
            http=http,
            https=https,
            ftp=ftp,
        )
        logger.debug(f'RequestsConfig :: CREATE PROXY :: {proxy}')

    def delete_proxies(self):
        self.proxies = []
        logger.info(f'RequestsConfig :: DELETE PROXIES :: DONE')
        return self

    def get_random_proxy(self) -> dict:
        """get random proxy"""
        if self.proxies:
            return random.choice(self.proxies)

    def get_proxy(self) -> dict:
        """get first proxy"""
        if self.proxies:
            return self.proxies[0]

    @property
    def is_ready(self):
        return f'{NotImplemented}'



import re
import random
import selenium.webdriver

from automon import log
from automon.helpers.osWrapper import environ

logger = log.logging.getLogger(__name__)
logger.setLevel(log.DEBUG)


class SeleniumConfig(object):
    def __init__(self):
        self._webdriver = None
        self.webdriver_wrapper = None

        self.cookies_autosave: bool = environ('SELENIUM_COOKIES_AUTOSAVE', False)
        self._cookies_base64 = environ('SELENIUM_COOKIES_BASE64')
        self._cookies_file = environ('SELENIUM_COOKIES_FILE')

        self.proxies = []
        self.use_random_proxy = False

    def add_proxy(self, proxy: str):
        """add proxy"""

        if not re.compile(r'\d+.\d+.\d+.\d+:\d+').match(proxy):
            raise ValueError(f'SeleniumConfig :: ADD PROXY :: ERROR :: bad proxy format (e.g. IP:PORT) :: {proxy=}')

        self.proxies.append(proxy)

        logger.debug(f'SeleniumConfig :: ADD PROXY :: {proxy}')
        logger.info(f'SeleniumConfig :: ADD PROXY :: DONE')
        return self

    def delete_proxies(self):
        self.proxies = []
        logger.info(f'SeleniumConfig :: DELETE PROXIES :: DONE')
        return self

    def get_random_proxy(self) -> str:
        """get random proxy"""
        if self.proxies:
            proxy = random.choice(self.proxies)
            logger.debug(f'SeleniumConfig :: GET RANDOM PROXY :: {proxy}')
            return proxy

    def get_proxy(self) -> dict:
        """get first proxy"""
        if self.proxies:
            proxy = self.proxies[0]
            logger.debug(f'SeleniumConfig :: GET PROXY :: {proxy}')
            return proxy

    @property
    def webdriver(self):
        try:
            return self.webdriver_wrapper.webdriver
        except:
            return self._webdriver

    @property
    def window_size(self):
        """get window size"""
        if self.webdriver_wrapper:
            return self.webdriver_wrapper.window_size

    @property
    def cookies_base64(self):
        logger.debug(
            f'SeleniumConfig :: COOKIES BASE64 :: {len(self._cookies_base64) / 1024 if self._cookies_base64 else None} KB')
        return self._cookies_base64

    @property
    def cookies_file(self):
        logger.debug(f'SeleniumConfig :: COOKIES FILE :: {self._cookies_file}')
        return self._cookies_file

    def run(self):
        """run webdriver"""
        logger.debug(f'SeleniumConfig :: RUN :: ')

        if self.proxies:
            if self.use_random_proxy:
                proxy = self.get_random_proxy()
            else:
                proxy = self.get_proxy()

            logger.debug(f'SeleniumConfig :: RUN :: ADD PROXY :: {proxy}')
            self.webdriver_wrapper.enable_proxy(proxy=proxy)

        run = self.webdriver_wrapper.run()
        self._webdriver = self.webdriver_wrapper.webdriver
        logger.debug(f'SeleniumConfig :: RUN :: {self.webdriver=}')
        logger.info(f'SeleniumConfig :: RUN :: DONE')
        return run

    def start(self):
        """alias to run"""
        return self.run()

    def quit(self):
        """quit webdriver"""
        return NotImplemented



import json
import requests

from automon import log
from .config import RequestsConfig

logger = log.logging.getLogger(__name__)
logger.setLevel(log.DEBUG)


class RequestsClient(object):
    def __init__(self, url: str = None, data: dict = None, headers: dict = None,
                 config: RequestsConfig = None):
        """Wrapper for requests library"""

        self.config = config or RequestsConfig()

        self.url: str = url
        self.data: dict = data
        self.errors: bytes = b''
        self.headers: dict = headers
        self.response = None
        self.requests = requests
        self.session = self.requests.Session()
        self.proxies = self.config.get_proxy()

    def __repr__(self):
        return f'{self.__dict__}'

    def __len__(self):
        if self.content:
            len(self.content)

    def _log_result(self):
        if self.status_code == 200:
            msg = [
                'RequestsClient',
                self.response.request.method,
                self.response.url,
                self.proxies,
                f'{round(len(self.content) / 1024, 2)} KB',
                f'{self.status_code}',
            ]
            msg = ' :: '.join([str(x) for x in msg])
            return logger.debug(msg)

        msg = [
            'RequestsClient',
            self.response.request.method,
            self.response.url,
            self.proxies,
            f'{round(len(self.content) / 1024, 2)} KB',
            f'{self.status_code}',
            f'{self.content}'
        ]

        msg = ' :: '.join([str(x) for x in msg])
        return logger.error(msg)

    def _params(self, url, data, headers):
        if url is None:
            url = self.url

        if data is None:
            data = self.data

        if headers is None:
            headers = self.headers

        self.url = url
        self.data = data
        self.headers = headers
        return url, data, headers

    @property
    def content(self):
        if 'content' in dir(self.response):
            return self.response.content

    def content_to_dict(self):
        return self.to_dict()

    def delete(
            self,
            url: str = None,
            data: dict = None,
            headers: dict = None,
            **kwargs
    ) -> bool:
        """requests.delete"""

        url, data, headers = self._params(url, data, headers)

        self._set_proxy()

        logger.debug(f'RequestsClient :: DELETE :: {url=} :: {data=} :: {headers=} :: {self.proxies=} :: {kwargs=}')

        try:
            self.response = self.session.delete(url=url, data=data, headers=headers, proxies=self.proxies, **kwargs)
            self._log_result()

            if self.status_code == 200:
                return True

            return False
        except Exception as error:
            self.errors = error
            logger.error(f'RequestsClient :: DELETE :: ERROR :: {error=}')
        return False

    def _set_proxy(self):
        if self.config.proxies:
            if self.config.use_random_proxies:
                self.proxies = self.config.get_random_proxy()
            else:
                self.proxies = self.config.get_proxy()

        logger.debug(f'RequestsClient :: SET PROXY :: {self.proxies}')

    def get(
            self,
            url: str = None,
            data: dict = None,
            headers: dict = None,
            **kwargs
    ) -> bool:
        """requests.get"""

        url, data, headers = self._params(url, data, headers)

        self._set_proxy()

        logger.debug(f'RequestsClient :: GET :: {url=} :: {data=} :: {headers=} :: {self.proxies=} :: {kwargs=}')

        try:
            self.response = self.session.get(url=url, data=data, headers=headers, proxies=self.proxies, **kwargs)
            self._log_result()

            if self.status_code == 200:
                return True

            self.errors = self.content

            return False
        except Exception as error:
            self.errors = error
            logger.error(f'RequestsClient :: GET :: ERROR :: {error=}')
        return False

    def patch(
            self,
            url: str = None,
            data: dict = None,
            headers: dict = None,
            **kwargs
    ) -> bool:
        """requests.patch"""

        url, data, headers = self._params(url, data, headers)

        self._set_proxy()

        logger.debug(f'RequestsClient :: PATCH :: {url=} :: {data=} :: {headers=} :: {self.proxies=} :: {kwargs=}')

        try:
            self.response = self.session.patch(url=url, data=data, headers=headers, proxies=self.proxies, **kwargs)
            self._log_result()

            if self.status_code == 200:
                return True

            self.errors = self.content

            return False
        except Exception as error:
            self.errors = error
            logger.error(f'RequestsClient :: PATCH :: ERROR :: {error=}')
        return False

    def post(
            self,
            url: str = None,
            data: dict = None,
            headers: dict = None,
            **kwargs
    ) -> bool:
        """requests.post"""

        url, data, headers = self._params(url, data, headers)

        self._set_proxy()

        logger.debug(f'RequestsClient :: POST :: {url=} :: {data=} :: {headers=} :: {self.proxies=} :: {kwargs=}')

        try:
            self.response = self.session.post(url=url, data=data, headers=headers, proxies=self.proxies, **kwargs)
            self._log_result()

            if self.status_code == 200:
                return True

            self.errors = self.content

            return False
        except Exception as error:
            self.errors = error
            logger.error(f'RequestsClient :: POST :: ERROR :: {error=}')
        return False

    def put(
            self,
            url: str = None,
            data: dict = None,
            headers: dict = None,
            **kwargs
    ) -> bool:
        """requests.put"""

        url, data, headers = self._params(url, data, headers)

        self._set_proxy()

        logger.debug(f'RequestsClient :: PUT :: {url=} :: {data=} :: {headers=} :: {self.proxies=} :: {kwargs=}')

        try:
            self.response = self.session.put(url=url, data=data, headers=headers, proxies=self.proxies, **kwargs)
            self._log_result()

            if self.status_code == 200:
                return True

            self.errors = self.content

            return False
        except Exception as error:
            self.errors = error
            logger.error(f'RequestsClient :: PUT :: ERROR :: {error=}')
        return False

    @property
    def reason(self):
        if 'reason' in dir(self.response):
            return self.response.reason

    @property
    def status_code(self):
        if 'status_code' in dir(self.response):
            return self.response.status_code

    @property
    def text(self):
        if self.response:
            return self.response.text

    def to_dict(self):
        if self.response is not None:
            try:
                return json.loads(self.content)
            except Exception as error:
                logger.error(f'RequestsClient :: TO DICT :: ERROR :: {error=}')

    def to_json(self):
        if self.content:
            try:
                return json.dumps(json.loads(self.content))
            except Exception as error:
                logger.error(f'RequestsClient :: TO JSON :: ERROR :: {error=}')

    def update_headers(self, headers: dict):
        return self.session.headers.update(headers)


class Requests(RequestsClient):
    pass
